@@ -10,8 +10,8 @@ dist.plot.hist.plot <- function(res,
                                 main.cex      = 1.2, 
                                 sub.cex       = 0.9, 
                                 bar.cex       = 0.8, 
-                                myoma         = c(2,2,2,2), ## c(2,3,2,2)
-                                mymar         = c(5,4,4,2)+0.1,
+                                myoma         = c(3,2,2,2), ## c(2,3,2,2)
+                                mymar         = c(5,4,1,2),
                                 width         = 0.5,
                                 ylim          = NULL,
                                 xlim          = NULL,
@@ -32,15 +32,15 @@ dist.plot.hist.plot <- function(res,
 
   if ( match.T ){ ## matching
     if ( !compare ){ ## no comparison
-      len.index <- nlevels(as.factor(res$index))-1
+      len.index <- nlevels(as.factor(res$index))-1 ## for original data
     }else{ ## comparison
       len.index <- nlevels(as.factor(res$index))
     }
-  }else{ ## no matching
+  }else{ ## stratification
     if ( !compare ){ ## no comparison
       len.index <- nlevels(as.factor(res$index))
     }else{ ## comparison
-      len.index <- nlevels(as.factor(res$index))+1 ## for unstratified/original data
+      len.index <- nlevels(as.factor(res$index))+1 ## for original data
     }
   }
 
@@ -55,28 +55,17 @@ dist.plot.hist.plot <- function(res,
       }
     }
   }else{
-    ##if (length(label.stratum) != 1){
-    ##  stop("Argument 'label.stratum' must be of length 1.")
-    ##}
     if ( !is.null(label.stratum) )
       if ( length(label.stratum) != 2 )
         stop("Argument 'label.stratum' must be of length 2.") 
   }
- 
+
+
+  
   ## #########################
   ## Non-categorical variables
   if( length(res$var.noncat)>0 ){    
     k <- 1
-    
-    #if ( with.legend == TRUE ){
-    #  width.bars <- rep(width, (len.index*len.treat))
-    #  ylim  <- c(0, (len.index*len.treat)+0.75)
-    #}#else{      
-    #  if( missing(width) )
-    #    width <- rep(0.9, (len.index*len.treat))
-    #  if(missing(ylim))
-    #    ylim  <- c(0, (len.index*len.treat)+0.5)
-    #}
         
     for( i in 1:length(res$var.noncat) ){       
       if( i>1 ) x11()
@@ -94,22 +83,35 @@ dist.plot.hist.plot <- function(res,
           co <- heat.colors(2)
       }
 
-      xl <- pretty(range(c(-res$x.noncat[[i]],
-                            res$y.noncat[[i]])))
-      xl <- c(xl[1], xl[length(xl)])
-
-      if ( with.legend==TRUE ){
-        ylim <- c(0, length(res$x.noncat[[i]])+1.5)
-        y.leg <- length(res$x.noncat[[i]])+1.4
-
-        if ( !match.T & (length(res$x.noncat[[i]])>5) ){
-          ylim <- c(0, length(res$x.noncat[[i]])+2)
-          y.leg <- length(res$x.noncat[[i]])+1.9
-        }
-        
+      if ( is.null(xlim) ){
+        xl <- pretty(range(c(-res$x.noncat[[i]],
+                             res$y.noncat[[i]])))
+        xl <- c(xl[1], xl[length(xl)])
       }else{
-        ylim <- c(0, length(res$x.noncat[[i]]))
+        xl <- xlim
       }
+
+      
+      if ( length(res$x.noncat[[i]])>3 ){ ## >5
+        ylim <- c(0, length(res$x.noncat[[i]])+2)
+        y.leg <- length(res$x.noncat[[i]])+2
+      }else{
+        ylim <- c(0, length(res$x.noncat[[i]])+1)  ## +1.5
+        y.leg <- length(res$x.noncat[[i]])+1       ## +0.8, +1.4
+      }
+      
+      #if ( with.legend==TRUE ){
+      #  ylim <- c(0, length(res$x.noncat[[i]])+1.0)  ## +1.5
+      #  y.leg <- length(res$x.noncat[[i]])+0.8       ## +1.4
+
+      #  ##if ( !match.T & (length(res$x.noncat[[i]])>5) ){
+      #  if ( length(res$x.noncat[[i]])>5 ){
+      #    ylim <- c(0, length(res$x.noncat[[i]])+2)
+      #    y.leg <- length(res$x.noncat[[i]])+1.9
+      #  } 
+      #}else{
+      #  ylim <- c(0, length(res$x.noncat[[i]]))
+      #}
   
       brks.axis <- vector(length=length(res$breaks.noncat[[i]])-1)        
       for (l in 1:(length(res$breaks.noncat[[i]])-1)){
@@ -141,7 +143,7 @@ dist.plot.hist.plot <- function(res,
                   space     = 0,
                   col       = co[1],
                   xlim      = xl,
-                  ylim = ylim,
+                  ylim      = ylim,
                   #ylim      = c(0, length(res$x.noncat[[i]])+1.5), ## +1
                   main      = main,
                   font.main = font.main,
@@ -195,14 +197,16 @@ dist.plot.hist.plot <- function(res,
           
           if (!match.T){                   
             mtext(paste(label.stratum[1],j),
-                  side = 1, line = 3, cex = bar.cex, font = font, ...)
-            mtext(paste("Distribution of", res$var.noncat[i]),
-                  side = 1, line = 4, cex = sub.cex, font = font, ...)
+                  side = 1, line = 5, cex = bar.cex, font = font, ...)
+            ##mtext(paste("Distribution of", res$var.noncat[i]),
+            mtext(res$var.noncat[i],
+                  side = 1, line = 3, cex = sub.cex, font = font, ...)
           }else{
             mtext(paste(levels(res$index)[2]," sample"),
-                  side = 1, line = 3, cex = bar.cex, font = font, ...)
-            mtext(paste("Distribution of", res$var.noncat[i]),
-                  side = 1, line = 4, cex = sub.cex, font = font, ...)
+                  side = 1, line = 5, cex = bar.cex, font = font, ...)
+            ##mtext(paste("Distribution of", res$var.noncat[i]),
+            mtext(res$var.noncat[i],
+                  side = 1, line = 3, cex = sub.cex, font = font, ...)
           }          
 
         }else{ ## j last stratum or original
@@ -278,23 +282,26 @@ dist.plot.hist.plot <- function(res,
           
           
           if (compare){
-            mtext(paste("Distribution of", res$var.noncat[i]),
-                  side = 1, line = 4, cex = sub.cex, font = font, ...)
+            ##mtext(paste("Distribution of", res$var.noncat[i]),
+            mtext(res$var.noncat[i],
+                  side = 1, line = 3, cex = sub.cex, font = font, ...)
             mtext(label.stratum[2],
-                      side = 1, line = 3, cex = bar.cex, font = font, ...)
+                      side = 1, line = 5, cex = bar.cex, font = font, ...)
           }else{
             if (!match.T){
               if (len.index != 1)
                 mtext(paste(label.stratum[1],j),
-                      side = 1, line = 3, cex = bar.cex, font = font, ...)
+                      side = 1, line = 5, cex = bar.cex, font = font, ...)
               
-              mtext(paste("Distribution of", res$var.noncat[i]),
-                    side = 1, line = 4, cex = sub.cex, font = font, ...)
+              ##mtext(paste("Distribution of", res$var.noncat[i]),
+              mtext(res$var.noncat[i],
+                    side = 1, line = 3, cex = sub.cex, font = font, ...)
             }else{
               mtext(paste(levels(res$index)[2]," sample"),
-                    side = 1, line = 3, cex = bar.cex, font = font, ...)
-              mtext(paste("Distribution of", res$var.noncat[i]),
-                    side = 1, line = 4, cex = sub.cex, font = font, ...)
+                    side = 1, line = 5, cex = bar.cex, font = font, ...)
+              ##mtext(paste("Distribution of", res$var.noncat[i]),
+              mtext(res$var.noncat[i],
+                    side = 1, line = 3, cex = sub.cex, font = font, ...)
             }
           }
         }
@@ -303,17 +310,16 @@ dist.plot.hist.plot <- function(res,
   }
   
 
-
+  ## #####################
   ## Categorical variables
-  if(length(res$var.cat)>0){    
-    for(i in 1:length(res$var.cat)){
-
-      
+  if( length(res$var.cat)>0 ){    
+    for( i in 1:length(res$var.cat) ){
+     
       if(i>1 || k>0)  x11()      
       
       par(mfrow=c(trunc(sqrt(len.index)),
-            ceiling(len.index/trunc(sqrt(len.index)))))
-      par(oma=myoma, mar=mymar)
+            ceiling(len.index/trunc(sqrt(len.index)))),
+          oma=myoma, mar=mymar)
       
       if (!is.null(col)){
         co <- col
@@ -323,45 +329,51 @@ dist.plot.hist.plot <- function(res,
         else
           co <- heat.colors(2)
       }
-      
-      xl <- pretty(range(c(-res$x.cat[[i]], res$y.cat[[i]])))
-      xl <- c(xl[1], xl[length(xl)])
 
-      if ( with.legend==TRUE ){
-        ylim <- c(0, length(res$x.cat[[i]])+1.5)  
-        y.leg <- length(res$x.cat[[i]])+1.4
-        
-        if ( !match.T & (length(res$x.cat[[i]])>5) ){
-          ylim <- c(0, length(res$x.cat[[i]])+2)
-          y.leg <- length(res$x.cat[[i]])+1.9
-        }
-          
+      if ( is.null(xlim) ){
+        xl <- pretty(range(c(-res$x.cat[[i]], res$y.cat[[i]])))
+        xl <- c(xl[1], xl[length(xl)])
       }else{
-        ylim <- c(0, length(res$x.cat[[i]]))
+        xl <- xlim
       }
-     
-      #if (is.factor(res$sel[, res$var.cat[i]])){
-      #  brks.axis <- levels(res$sel[, res$var.cat[i]])
-      #}else{ 
-      #  brks.axis <- seq(min(as.numeric(res$sel[,res$var.cat[i]])),
-      #                   max(as.numeric(res$sel[,res$var.cat[i]])),1)
-      #}
 
-      if (is.factor(res$sel[, res$var.cat[i]])){
+      if ( length(res$x.cat[[i]])>3 ){   ## >5
+        ylim <- c(0, length(res$x.cat[[i]])+2)
+        y.leg <- length(res$x.cat[[i]])+2
+      }else{
+        ylim <- c(0, length(res$x.cat[[i]])+1)  ## +1.5
+        y.leg <- length(res$x.cat[[i]])+1       ## +0.8, +1.4
+      }
+
+      #if ( with.legend==TRUE ){    
+      #  ylim <- c(0, length(res$x.cat[[i]])+1.0)  ## +1.5
+      #  y.leg <- length(res$x.cat[[i]])+0.8       ## +1.4
+      #  ## stratification with more than 5 breaks (5 strata or 4
+      #  ## str+original)
+      #  ## if ( !match.T & (length(res$x.cat[[i]])>5) ){
+      #  if ( length(res$x.cat[[i]])>5 ){
+      #    ylim <- c(0, length(res$x.cat[[i]])+2)
+      #    y.leg <- length(res$x.cat[[i]])+1.9
+      #  }
+      #}else{
+      #  ylim <- c(0, length(res$x.cat[[i]]))
+      #}
+     
+      if ( is.factor(res$sel[, res$var.cat[i]]) ){
         brks.axis <- levels(res$sel[, res$var.cat[i]])
       }else{
-        brks.axis <- levels(as.factor(round(res$sel[, res$var.cat[i]],3)))
-      
+        brks.axis <- levels(as.factor(round(res$sel[, res$var.cat[i]],3))) 
       }
       
       
       at.2 <- seq(0,length(res$x.cat[[i]])-1,1)+0.5
       
       
-      for (j in 1:len.index){      
-        if (j != len.index){
+      for ( j in 1:len.index ){      
+
+        if ( j != len.index ){
       
-          if (!match.T){ # no matching
+          if ( !match.T ){ # no matching
             x.to.plot <- res$x.s.cat[[i]][,j]
             y.to.plot <- res$y.s.cat[[i]][,j]
           }else{## matching
@@ -375,8 +387,7 @@ dist.plot.hist.plot <- function(res,
                   space     = 0,
                   col       = co[1],
                   xlim      = xl,
-                  ylim=ylim,
-                  #ylim      = c(0, length(res$x.cat[[i]])+1.5),
+                  ylim      = ylim,
                   main      = main,
                   font.main = font.main,
                   cex.main  = main.cex,    
@@ -391,7 +402,6 @@ dist.plot.hist.plot <- function(res,
                   axes  = FALSE,
                   xlim  = xl,
                   ylim=ylim,
-                  #ylim  = c(0, length(res$x.cat[[i]])+1.5),
                   ...
                   )
           
@@ -410,11 +420,10 @@ dist.plot.hist.plot <- function(res,
                ...
                )
 
-          if (with.legend)
+          if ( with.legend )
             legend(x         = 0,
                    xjust     = 0.5,
-                   y=y.leg,
-                   #y         = length(res$x.cat[[i]])+1.75,
+                   y         = y.leg,
                    legend    = levels(as.factor(res$treat)),
                    title     = legend.title,
                    bty       = "n",
@@ -424,16 +433,18 @@ dist.plot.hist.plot <- function(res,
                    x.intersp = 0.8,
                    horiz     = TRUE)
           
-          if (!match.T){                   
+          if ( !match.T ){                   
             mtext(paste(label.stratum[1],j),
-                  side=1, line=3, cex=bar.cex, font=font, ...)
-            mtext(paste("Distribution of", res$var.cat[i]),
-                  side=1, line=4, cex=sub.cex, font=font, ...)
+                  side=1, line=5, cex=bar.cex, font=font, ...)
+            ##mtext(paste("Distribution of", res$var.cat[i]),
+            mtext(res$var.cat[i],
+                  side=1, line=3, cex=sub.cex, font=font, ...)
           }else{
             mtext(paste(levels(res$index)[2]," sample"),
-                  side=1, line=3, cex=bar.cex, font=font, ...)
-            mtext(paste("Distribution of", res$var.cat[i]),
-                  side=1, line=4, cex=sub.cex, font=font, ...)
+                  side=1, line=5, cex=bar.cex, font=font, ...)
+            ##mtext(paste("Distribution of", res$var.cat[i]),
+            mtext(res$var.cat[i],
+                  side=1, line=3, cex=sub.cex, font=font, ...)
           } 
           
         }else{ ## j last stratum
@@ -444,7 +455,8 @@ dist.plot.hist.plot <- function(res,
           }else{ ## no comparison
             if (!match.T){
               
-              if ( length(res$x.cat[[i]]) == length(res$x.s.cat[[i]]) ){ ##object.class=pscore
+              if ( length(res$x.cat[[i]]) ==
+                  length(res$x.s.cat[[i]]) ){ ##object.class=pscore
 
                 x.to.plot <- res$x.s.cat[[i]]
                 y.to.plot <- res$y.s.cat[[i]]
@@ -466,8 +478,7 @@ dist.plot.hist.plot <- function(res,
                   space     = 0,
                   col       = co[1],
                   xlim      = xl,
-                  ylim=ylim,
-                  #ylim      = c(0, length(res$x.cat[[i]])+1.5),
+                  ylim      = ylim,
                   main      = main,
                   font.main = font.main,
                   cex.main  = main.cex,    
@@ -481,8 +492,7 @@ dist.plot.hist.plot <- function(res,
                   space = 0,
                   col   = co[2],
                   xlim  = xl,
-                  ylim=ylim,
-                  #ylim  = c(0, length(res$x.cat[[i]])+1.5),
+                  ylim  = ylim,
                   ...
                   )
           
@@ -505,8 +515,7 @@ dist.plot.hist.plot <- function(res,
           if (with.legend)
             legend(x         = 0,
                    xjust     = 0.5,
-                   y=y.leg,
-                   #y         = length(res$x.cat[[i]])+1.75,  ## +1
+                   y         = y.leg,
                    legend    = levels(as.factor(res$treat)),
                    title     = legend.title,
                    bty       = "n",
@@ -517,22 +526,25 @@ dist.plot.hist.plot <- function(res,
                    horiz     = TRUE)
           
           if (compare){
-            mtext(paste("Distribution of", res$var.cat[i]),
-                  side=1, line=4, cex=sub.cex, font=font, ...)
+            ##mtext(paste("Distribution of", res$var.cat[i]),
+            mtext(res$var.cat[i],
+                  side=1, line=3, cex=sub.cex, font=font, ...)
             mtext(label.stratum[2],
-                      side=1, line=3, cex=bar.cex, font=font, ...)
+                      side=1, line=5, cex=bar.cex, font=font, ...)
           }else{
             if (!match.T){
               if (len.index != 1)
                 mtext(paste(label.stratum[1],j),
-                      side=1, line=3, cex=bar.cex, font=font, ...)
-              mtext(paste("Distribution of", res$var.cat[i]),
-                    side=1, line=4, cex=sub.cex, font=font, ...)
+                      side=1, line=5, cex=bar.cex, font=font, ...)
+              ##mtext(paste("Distribution of", res$var.cat[i]),
+              mtext(res$var.cat[i],
+                    side=1, line=3, cex=sub.cex, font=font, ...)
             }else{
               mtext(paste(levels(res$index)[2]," sample"),
-                    side=1, line=3, cex=bar.cex, font=font, ...)
-              mtext(paste("Distribution of", res$var.cat[i]),
-                    side=1, line=4, cex=sub.cex, font=font, ...)
+                    side=1, line=5, cex=bar.cex, font=font, ...)
+              ##mtext(paste("Distribution of", res$var.cat[i]),
+              mtext(res$var.cat[i],
+                    side=1, line=3, cex=sub.cex, font=font, ...)
             }
           }
         }
