@@ -28,25 +28,30 @@ print.matched.data.frame <- function(object,
   df.treat <- as.vector(object$data[names(object$data)==object$name.treat])
   
   cat("\n Matching data:\n")
-
-  print(matrix(c(length(object$match.index[object$match.index>0]),
+  
+  print(matrix(c(length(object$match.index[df.treat==object$match.parameters$who.treated]),
                  length(object$match.index[object$match.index>0 &
-                                           df.treat==object$match.parameter$who.treated]),
+                                           df.treat==object$match.parameters$who.treated]),
+                 length(object$match.index[df.treat!=object$match.parameters$who.treated]),
                  length(object$match.index[object$match.index>0 &
-                                           df.treat!=object$match.parameter$who.treated]),
+                                           df.treat!=object$match.parameters$who.treated]),
+                 length(object$match.index[object$match.index>0]),
                  length(object$match.index[object$match.index==0]),
                  length(unique(object$match.index))-1,
                  sum(as.numeric(table(object$match.index[object$match.index>0])) !=
-                     (object$match.parameter$ratio +1))),
-               nrow=6,ncol=1,
+                     (object$match.parameters$ratio +1))),
+               nrow=8,ncol=1,
                dimnames=
-               list(c("Number of matched obs:",
-                      "Number of matched treated obs:",
-                      "Number of matched untreated obs:",
-                      "Number of dropped obs:",
+               list(c("Number of treated obs.:",
+                      "Number of matched treated obs.:",
+                      "Number of untreated obs.:",
+                      "Number of matched untreated obs.:",
+                      "Number of total matched obs.:",
+                      "Number of not matched obs.:",
                       "Number of matching sets:",
-                      "Number of incomplete matching sets:"), c(""))))
-  
+                      "Number of incomplete matching sets:"), c("")))
+        )
+          
 }
 
 
